function img = Filter1(img,distance,dpi)

% This function applies the filter from the 1992 paper entitled
% ''Optimized Error Diffusion for High Quality Image Display''
% in the YCxCz domain. The filter uses the Nasanen model for L,
% and is designed to match Mullen's data for the chrominance components.

% Compute magnitude of frequency in units of samples form (0,0) frequency
[height,width,Ncolors] = size(img);
[jj,ii] = meshgrid(1:width,1:height);
hoffset = (height/2)+1;
woffset = (width/2)+1;

% Compute spatial frequecy scaling
fs = pi*distance*dpi/180;
fmag = sqrt( ((fs/height)*(ii-hoffset)).^2 + ((fs/width)*(jj-woffset)).^2);

% Compute frequency angle
theta = atan2(ii-hoffset,jj-woffset);
stheta = ((1-0.7)/2)*cos(4*theta) + ((1+0.7)/2);
tildefmag = fmag./stheta;

% Coeffiences of Nasanen and Sullivan model
L = 11.0;
a = 131.6;
b = 0.3188;
c = 0.525;
d = 3.91;
alpha = 0.419;
A = 100;

% Frequency response curves for the YCxCz/Lab model
% from the 1992 paper entitled
% ''Optimized Error Diffusion for High Quality Image Display''
wL = a*(L^b)*exp(-tildefmag*(1/(c*log(L)+d)));
wC = A*exp(-alpha*fmag);

wL = fftshift(wL);
wC = fftshift(wC);

% Filter components of image
imgY  = img(:,:,1);
imgCx = img(:,:,2);
imgCz = img(:,:,3);

imgY  = ifft2(wL.*fft2(imgY));
imgCx = ifft2(wC.*fft2(imgCx));
imgCz = ifft2(wC.*fft2(imgCz));

img(:,:,1) = imgY;
img(:,:,2) = imgCx;
img(:,:,3) = imgCz;

%max(max(max(abs(imag(img)))))
img = real(img);

