function img = Filter2(img,distance,dpi)

% This function applies the filter from the 1995 paper entitled
% ''Optimized Universal Color Palette Design for Error Diffusion''
% in the YCxCz domain. The filter is designed so that its DC
% response is 1.

% Compute magnitude of frequency in units of samples form (0,0) frequency
[height,width,Ncolors] = size(img);
[jj,ii] = meshgrid(1:width,1:height);
hoffset = (height/2)+1;
woffset = (width/2)+1;

% Compute spatial frequecy scaling
fs = pi*distance*dpi/180;
fmag = sqrt( ((fs/height)*(ii-hoffset)).^2 + ((fs/width)*(jj-woffset)).^2);

% Constanstants with corrected transposition error
c1 = 0.1761;
c2 = 0.4385;
c3 = 2.2610;
c4 = 0.2048;
                                                                                
% Originally published (but transposed) constants
%c1 = 0.4385;
%c2 = 0.1761;
                                                                                
% Frequency response curves for the YCxCz/Lab model
% from the 1995 paper entitled
% ''Optimized Universal Color Palette Design for Error Diffusion''
wL = min(1,exp(-c1*(fmag-c3)));
wL = fftshift(wL);
wC = min(1,exp(-c2*(fmag-c4)));
wC = fftshift(wC);

% Filter components of image
imgY  = img(:,:,1);
imgCx = img(:,:,2);
imgCz = img(:,:,3);

imgY  = ifft2(wL.*fft2(imgY));
imgCx = ifft2(wC.*fft2(imgCx));
imgCz = ifft2(wC.*fft2(imgCz));

img(:,:,1) = imgY;
img(:,:,2) = imgCx;
img(:,:,3) = imgCz;

%max(max(max(abs(imag(img)))))
img = real(img);

